==> cook.1.7.tar.gz: cook.1.7/test/00/t0031a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1990, 1991, 1992, 1993, 1994 Peter Miller.
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# MANIFEST: test the os_stat_cache() function
#
tmp=/tmp/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 1; fi

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

fail()
{
	echo 'FAILED test of the os_stat_chache() function of cook' 1>&2
	cd $here
	rm -rf $tmp
	exit 1
}
pass()
{
	cd $here
	rm -rf $tmp
	exit 0
}
trap "fail" 1 2 3 15

mkdir $tmp
cd $tmp

mkdir a a/b a/b/c
cp /dev/null a/fubar

cat > Howto.cook <<foobar
test: test1 test2 test3 test4 test5 test6 test7;
test1: { if [not [exists Howto.cook]] then fail; }
test2: { if [exists snot] then fail; }
test3: { if [not [exists a/fubar]] then fail; }
test4: { if [exists a/fubar/b/c] then fail; }
test5: { if [not [exists a]] then fail; }
test6: { if [not [exists a/b]] then fail; }
test7: { if [not [exists a/b/c]] then fail; }
foobar
if test $? -ne 0 ; then fail; fi

$bin/cook -nl -tr > /dev/null 2>&1
if test $? -ne 0 ; then fail; fi

# probably OK
pass

==> cook_2.26.orig.tar.gz: cook-2.26/test/00/t0031a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997, 1998 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: test the os_stat_cache() function
#
tmp=${COOK_TMP:-/tmp}/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 1; fi

bin="$here/${1-.}/bin"

fail()
{
	echo 'FAILED test of the os_stat_chache() function of cook' 1>&2
	cd $here
	rm -rf $tmp
	exit 1
}
pass()
{
	cd $here
	rm -rf $tmp
	exit 0
}
trap "fail" 1 2 3 15

mkdir $tmp $tmp/lib
cd $tmp

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG

mkdir a a/b a/b/c
cp /dev/null a/fubar

cat > Howto.cook <<foobar
test: test1 test2 test3 test4 test5 test6 test7;
test1: { if [not [exists Howto.cook]] then fail; }
test2: { if [exists snot] then fail; }
test3: { if [not [exists a/fubar]] then fail; }
test4: { if [exists a/fubar/b/c] then fail; }
test5: { if [not [exists a]] then fail; }
test6: { if [not [exists a/b]] then fail; }
test7: { if [not [exists a/b/c]] then fail; }
foobar
if test $? -ne 0 ; then fail; fi

$bin/cook -nl -tr > /dev/null 2>&1
if test $? -ne 0 ; then fail; fi

# probably OK
pass
